@@ -1,4 +1,8 @@
 #!/usr/bin/env python3
+# Copyright (c) 2004-present Facebook All rights reserved.
+# Use of this source code is governed by a BSD-style
+# license that can be found in the LICENSE file.
+
 import glob
 from enum import Enum
 import json
@@ -6,7 +10,12 @@ import os
 import requests
 from typing import Tuple
 
-from graphql import build_ast_schema, build_client_schema, get_introspection_query
+from graphql import (
+    build_ast_schema,
+    build_client_schema,
+    get_introspection_query,
+    GraphQLSchema,
+)
 from graphql.language.parser import parse
 from graphql.language import OperationDefinitionNode, FragmentDefinitionNode
 from graphql.language.ast import DocumentNode
@@ -42,7 +51,7 @@ def load_schema(uri):
     return build_client_schema(introspection)
 
 
-def compile_schema_library(schema_library: str):
+def compile_schema_library(schema_library: str) -> GraphQLSchema:
     full_schema = ""
     # use the following line to use .graphqls files as well
     # os.path.join(schema_library, "**/*.graphql*"), recursive=True
